Module error

Module error 

Crate-wide error types

Enums

ClientError
Error returned by access point and station clients if there is a problem with the request e.g. asking to select a network you have not created a config for
ParseError
A sub error of ClientError returned when there is a problem parsing the response from the socket. This is probably a bug in the wifi_ctrl code.
SocketError
Error returned by access point and station runners if there is a problem with the control socket. e.g. if wpa_supplicant is restarted