pub enum ClientError {
Failed,
ParsingResponse {
error: ParseError,
failed_response: String,
},
Timeout,
DidNotWriteAllBytes(usize, usize),
RunnerNotRunning,
PendingSelect,
InvalidPsk,
InvalidBssid,
}Expand description
Error returned by access point and station clients if there is a problem with the request e.g. asking to select a network you have not created a config for
Variants
Failed
Request failed e.g. asking to select a network you have not created a config for
ParsingResponse
Error parsing the response from the socket. This is probably a bug in the wifi_ctrl code.
Timeout
Timeout waiting for response to request on control socket
DidNotWriteAllBytes(usize, usize)
Request was too big to fit in a datagram, most likely seen on bad custom requests
RunnerNotRunning
The control socket is not connected at the moment, reconnect and try again
PendingSelect
A select request is already pending; wait for it to resolve before selecting again
InvalidPsk
A PSK passphrase was not 8-63 printable-ASCII characters, or contained a double-quote, which cannot be safely encoded for wpa_supplicant
InvalidBssid
A BSSID was not a well-formed xx:xx:xx:xx:xx:xx MAC address