pub enum SocketError {
Io(Error),
StartupAborted,
ClientChannelClosed,
TimeoutOpeningSocket(String),
PermissionDeniedOpeningSocket(String),
AttachFailed(String),
}Expand description
Error returned by access point and station runners if there is
a problem with the control socket. e.g. if wpa_supplicant is restarted
Variants
Io(Error)
IO error from control socket
StartupAborted
Client asked runner to shutdown
ClientChannelClosed
RequestClient dropped without shutting down runner
TimeoutOpeningSocket(String)
Timeout trying to open the control socket even after retrying
PermissionDeniedOpeningSocket(String)
Permission denied opening control socket
AttachFailed(String)
A control command kept failing while registering the event stream, even after retrying