pub struct WifiSetup { /* private fields */ }Expand description
Setup struct for the WiFiAp process.
Implementations
Sourceimpl WifiSetup
impl WifiSetup
pub fn new() -> Self
Sourcepub fn with_capacities(
request_channel_size: usize,
broadcast_channel_size: usize,
) -> Self
pub fn with_capacities( request_channel_size: usize, broadcast_channel_size: usize, ) -> Self
Like Self::new but with explicit request and broadcast channel
capacities (both default to 32).
pub fn set_socket_path<S: Into<PathBuf>>(&mut self, path: S)
pub fn add_attach_options(&mut self, options: &[&str])
Sourcepub fn set_command_timeout(&mut self, timeout: Duration)
pub fn set_command_timeout(&mut self, timeout: Duration)
Set how long to wait for a reply to a control command/request before
giving up with ClientError::Timeout.
Sourcepub fn set_attach_retries(&mut self, retries: usize)
pub fn set_attach_retries(&mut self, retries: usize)
Set how many times to retry the hostapd ATTACH/LOG_LEVEL handshake
before giving up with
SocketError::AttachFailed.
Sourcepub fn set_attach_retry_delay(&mut self, delay: Duration)
pub fn set_attach_retry_delay(&mut self, delay: Duration)
Set how long to wait between attach handshake attempts.
pub fn get_broadcast_receiver(&self) -> BroadcastReceiver
pub fn get_request_client(&self) -> RequestClient
pub fn complete(self) -> WifiAp