Crate-wide error types
Enums
- Client
Error - Error returned by access point and station clients if there is a problem with the request e.g. asking to select a network you have not created a config for
- Parse
Error - A sub error of
ClientErrorreturned when there is a problem parsing the response from the socket. This is probably a bug in thewifi_ctrlcode. - Socket
Error - Error returned by access point and station runners if there is
a problem with the control socket. e.g. if
wpa_supplicantis restarted